@@ -2,11 +2,14 @@
 
 package Devel::AssertOS::OSFeatures::POSIXShellRedirection;
 
-$VERSION = '1.3';
+our $VERSION = '1.4';
 
 use Devel::CheckOS;
+use strict;
+use warnings;
+no warnings 'redefine';
 
-sub matches { return qw(Unix Cygwin BeOS); }
+sub matches { return qw(Unix Cygwin BeOS VOS); }
 sub os_is { Devel::CheckOS::os_is(matches()); }
 Devel::CheckOS::die_unsupported() unless(os_is());
 
@@ -22,7 +25,6 @@ join("\n",
 )
 }
 
-
 =head1 NAME
 
 Devel::AssertOS::OSFeatures::POSIXShellRedirection - check whether
